{% load static %}
<!--[if IE 8]><html xmlns="http://www.w3.org/1999/xhtml" class="ie8" lang="en-US"><![endif]-->
<!--[if !(IE 8) ]><!-->
<!DOCTYPE html>
<html lang="en-US">
<!--<![endif]-->
<head>
  <meta content="text/html; charset=utf-8" http-equiv="Content-Type">
  <title>Log In &lsaquo; {{ name }} &#8212; WordPress</title>
  <link href='//s.w.org' rel='dns-prefetch'>
  {# <script src='{{ request.scheme }}://{{ domain }}/wp-admin/load-scripts.php?c=1&amp;load%5B%5D=jquery-core,jquery-migrate&amp;ver=4.7' type='text/javascript'></script> #}
  <link href='{% static 'css/wordpress.css' %}' media='all' rel='stylesheet' type='text/css'>
  <meta content='noindex,follow' name='robots'>
  <meta content="width=device-width" name="viewport">
</head>
<body class="login login-action-login wp-core-ui locale-en-us">
  <div id="login">
    <h1><a href="https://wordpress.org/" tabindex="-1" title="Powered by WordPress">Powered by WordPress</a></h1>
    <form action="{{ request.scheme }}://{{ domain }}/wp-login.php?wpe-login=true" id="loginform" method="post" name="loginform">
      <p>
        <label for="user_login">Username or Email Address<br>
          <input class="input" id="user_login" name="log" size="20" type="text" value="">
        </label>
      </p>
      <p>
        <label for="user_pass">Password<br>
          <input class="input" id="user_pass" name="pwd" size="20" type="password" value="">
        </label>
      </p>
      <p class="forgetmenot">
        <label for="rememberme">
          <input id="rememberme" name="rememberme" type="checkbox" value="forever"> Remember Me
        </label>
      </p>
      <p class="submit">
        <input class="button button-primary button-large" id="wp-submit" name="wp-submit" type="submit" value="Log In">
        <input name="redirect_to" type="hidden" value="{{ request.scheme }}://{{ domain }}/wp-admin/">
        <input name="testcookie" type="hidden" value="1">
      </p>
    </form>
    <p id="nav"><a href="{{ request.scheme }}://{{ domain }}/wp-login.php?action=lostpassword">Lost your password?</a></p>
    <script type="text/javascript">
    function wp_attempt_focus() {
      setTimeout(function() {
        try {
          d = document.getElementById('user_login');
          d.focus();
          d.select();
        } catch (e) {}
      }, 200);
    }
    wp_attempt_focus();
    if (typeof wpOnload == 'function') wpOnload();
    </script>
    <p id="backtoblog"><a href="{{ request.scheme }}://{{ domain }}/">&larr; Back to {{ name }}</a></p>
    <div class="privacy-policy-page-link"></div>
  </div>
  <div class="clear"></div>
</body>
</html>
